### Name: jags
### Title: Run jags from R
### Aliases: rjags-class jags jags2
### Keywords: interface models

### ** Examples

  # An example model file is given in:
  model.file <- system.file(package="R2jags", "model", "schools.txt")
  # Let's take a look:
  file.show(model.file)

  # data
  J <- 8.0
  y <- c(28.4,7.9,-2.8,6.8,-0.6,0.6,18.0,12.2)
  sd <- c(14.9,10.2,16.3,11.0,9.4,11.4,10.4,17.6)

  jags.data <- list("y","sd","J")
  jags.params <- c("mu","sigma","theta")
  jags.inits <- function(){
    list("mu"=rnorm(1),"sigma"=runif(1),"theta"=rnorm(J))
  }
  
#=============#
# using jags  #
#=============#
  jagsfit <- jags(data=jags.data, inits=jags.inits, jags.params, 
    n.iter=5000, model.file=model.file)
    
  # display the output
  print(jagsfit)
  plot(jagsfit)
  
  # traceplot
  traceplot(jagsfit)
  
  # if the model does not converge, update it!
  jagsfit.upd <- update(jagsfit, n.iter=1000)
  print(jagsfit.upd)
  plot(jagsfit.upd)
  
  # or auto update it until it converges! see ?autojags for details
  jagsfit.upd <- autojags(jagsfit)
    
  # to get DIC or specify DIC=TRUE in jags()
  dic.samples(jagsfit.upd$model, n.iter=1000, type="pD")

  # to pick up the last save session
  # for example, load("RWorkspace.Rdata")
  recompile(jagsfit)
  jagsfit.upd <- update(jagsfit)

#=============#
# using jags2 #
#=============#
  ## jags cannot be updated, but produces coda files
  ## You may need to edit "jags.path",
  ## also you need write access in the working directory:
  ## currently works only under Windows OS
  ## e.g. setwd("c:/")
  
  #jagsfit <- jags2(data=jags.data, inits=jags.inits, jags.params, 
  #  n.iter=5000, model.file=model.file)
  #print(jagsfit)
  #plot(jagsfit)



